@@ -2,9 +2,10 @@ from copy import deepcopy
 
 from django.utils.translation import gettext_lazy as _
 
-from cms.contexts.models import CreatedModifiedBy, WebPath, models, settings
+from cms.contexts.models import WebPath, models, settings
 from cms.contexts.models_abstract import AbstractLockable
 from cms.templates.models import (ActivableModel,
+                                  CreatedModifiedBy,
                                   SortableModel,
                                   TimeStampedModel)
 
@@ -79,7 +80,7 @@ class NavigationBarItem(TimeStampedModel, SortableModel, ActivableModel,
     name = models.CharField(max_length=60, blank=False, null=False)
     webpath = models.ForeignKey(WebPath,
                                 null=True, blank=True,
-                                on_delete=models.CASCADE,
+                                on_delete=models.SET_NULL,
                                 related_name="linked_page")
     parent = models.ForeignKey('NavigationBarItem',
                                null=True, blank=True,
@@ -90,11 +91,11 @@ class NavigationBarItem(TimeStampedModel, SortableModel, ActivableModel,
     publication = models.ForeignKey('cmspublications.Publication',
                                     null=True, blank=True,
                                     related_name='pub',
-                                    on_delete=models.CASCADE)
+                                    on_delete=models.SET_NULL)
     inherited_content = models.ForeignKey('cmspublications.Publication',
                                           null=True, blank=True,
                                           related_name='inherited_content',
-                                          on_delete=models.CASCADE,
+                                          on_delete=models.SET_NULL,
                                           help_text=_("Takes additional "
                                                       "contents from a "
                                                       "publication"))
@@ -108,22 +109,26 @@ class NavigationBarItem(TimeStampedModel, SortableModel, ActivableModel,
             raise Exception(_("Can't choose a child as parent!"))
         super(self.__class__, self).save(*args, **kwargs)
 
-    @property
-    def link(self):
+    # @property
+    def link(self, request=None):
         if self.url:
             return self.url
         elif self.webpath:
-            if self.publication:
-                ctx_webpath = self.publication.get_publication_context(webpath=self.webpath)
-                return ctx_webpath.url if ctx_webpath else ''
-            else:
-                return self.webpath.get_full_path()
+            # does it have sense?
+            # if self.publication:
+                # ctx_webpath = self.publication.get_publication_context(webpath=self.webpath)
+                # return ctx_webpath.url if ctx_webpath else ''
+            # else:
+            # return self.webpath.get_full_path()
+            return self.webpath.get_site_path(request)
         else: # pragma: no cover
             return ''
 
     def localized(self, lang=settings.LANGUAGE, **kwargs):
         i18n = NavigationBarItemLocalization.objects.filter(item=self,
-                                                            language=lang).first()
+                                                            language=lang,
+                                                            is_active=True)\
+                                                    .first()
         if i18n: # pragma: no cover
             self.name = i18n.name
             self.language = lang
@@ -142,7 +147,7 @@ class NavigationBarItem(TimeStampedModel, SortableModel, ActivableModel,
                     url = self.url,
                     publication_id = self.publication.pk if self.publication else None,
                     webpath_id = self.webpath.pk if self.webpath else None,
-                    link = self.link,
+                    link = self.link(),
                     is_active = self.is_active,
                     order = self.order,
                     level=level
@@ -155,13 +160,18 @@ class NavigationBarItem(TimeStampedModel, SortableModel, ActivableModel,
                 data['childs'].append(ser_child)
         return data
 
-    def get_childs(self, lang=settings.LANGUAGE, only_active=True):
+    def get_childs(self,
+                   lang=settings.LANGUAGE,
+                   only_active=True,
+                   exclude=None):
         if self.pk:
             items = NavigationBarItem.objects.filter(parent=self,
                                                      menu=self.menu).\
                                               order_by('order')
             if only_active:
                 items = items.filter(is_active=True)
+            if exclude:
+                items = items.exclude(pk=exclude.pk)
             # if getattr(self, 'language', lang):
             for item in items:
                 item.localized(lang)
