@@ -1,4 +1,5 @@
 from django.db import models
+from django.utils import timezone
 from django.utils.text import slugify
 from django.utils.translation import gettext_lazy as _
 
@@ -81,7 +82,7 @@ class AbstractPublication(TimeStampedModel, ActivableModel):
                                     max_length=33,
                                     default='html')
     presentation_image = models.ForeignKey(Media, null=True, blank=True,
-                                           on_delete=models.CASCADE)
+                                           on_delete=models.PROTECT)
     # state = models.CharField(choices=PAGE_STATES,
     # max_length=33,
     # default='draft')
@@ -125,11 +126,17 @@ class Publication(AbstractPublication, CreatedModifiedBy, AbstractLockable):
                                                       is_active=True)
 
     def image_url(self):
+        image_path = ''
         if self.presentation_image:
             image_path = self.presentation_image.file
         else: # pragma: no cover
-            image_path = self.category.first().image
-        return sanitize_path(f'{settings.MEDIA_URL}/{image_path}')
+            categories = self.category.all()
+            for category in categories:
+                if category.image:
+                    image_path = category.image
+                    break
+        return sanitize_path(f'{settings.MEDIA_URL}/{image_path}') \
+            if image_path else image_path
 
     @property
     def categories(self):
@@ -290,6 +297,10 @@ class Publication(AbstractPublication, CreatedModifiedBy, AbstractLockable):
         # if no permissions
         return False
 
+    @property
+    def is_publicable(self) -> bool:
+        return self.is_active
+
     def is_publicable_by(self, user=None):
         if not user: return False
 
@@ -320,7 +331,7 @@ class PublicationContext(TimeStampedModel, ActivableModel,
                          AbstractPublicable, SectionAbstractModel,
                          SortableModel, CreatedModifiedBy):
     publication = models.ForeignKey(Publication, null=False, blank=False,
-                                    on_delete=models.CASCADE)
+                                    on_delete=models.PROTECT)
     webpath = models.ForeignKey(WebPath, on_delete=models.CASCADE)
     date_start = models.DateTimeField()
     date_end = models.DateTimeField()
@@ -366,6 +377,11 @@ class PublicationContext(TimeStampedModel, ActivableModel,
         result['path'] = self.url
         return result
 
+    @property
+    def is_publicated(self) -> bool:
+        now = timezone.localtime()
+        return self.date_start <= now and self.date_end >= now
+
     def __str__(self):
         return '{} {}'.format(self.publication, self.webpath)
 
@@ -376,7 +392,7 @@ class PublicationRelated(TimeStampedModel, SortableModel, ActivableModel,
                                     related_name='parent_publication',
                                     on_delete=models.CASCADE)
     related = models.ForeignKey(Publication, null=False, blank=False,
-                                on_delete=models.CASCADE,
+                                on_delete=models.PROTECT,
                                 related_name="related_publication")
 
     class Meta:
@@ -405,7 +421,7 @@ class PublicationBlock(SectionAbstractModel,TimeStampedModel,
     publication = models.ForeignKey(Publication, null=False, blank=False,
                                     on_delete=models.CASCADE)
     block = models.ForeignKey(TemplateBlock, null=False, blank=False,
-                              on_delete=models.CASCADE)
+                              on_delete=models.PROTECT)
 
     class Meta:
         verbose_name_plural = _("Publication Page Block")
@@ -422,7 +438,7 @@ class PublicationGallery(TimeStampedModel, ActivableModel, SortableModel,
     publication = models.ForeignKey(Publication,
                                     on_delete=models.CASCADE)
     collection = models.ForeignKey(MediaCollection,
-                                   on_delete=models.CASCADE)
+                                   on_delete=models.PROTECT)
 
     class Meta:
         verbose_name_plural = _("Publication Image Gallery")
